.. warning::

    This documentation is still a work in progress. If you have any issues or
    questions, please ask on the stix-discussion mailing list or file a bug
    in our `issue tracker`_.

.. _issue tracker: https://github.com/STIXProject/python-stix/issue


